@@ -15,7 +15,7 @@ import os
 import sys
 import time
 from glob import glob
-from . import ascii
+from pushing_outshoot_unfold import ascii
 	
 
 # Read days files, put it in days
@@ -24,14 +24,14 @@ try:
 	base_path = sys._MEIPASS
 except Exception:
 	base_path = os.path.abspath(os.path.dirname(__file__))
-filename = os.path.join(base_path, 'days*', '*.day')
+filename = os.path.join(base_path, 'days*', '*.toml')
 for filename in glob(filename):
 	print('Scanning file', filename)
-	name = filename.split(os.sep)[-1].split('.')[0]
-	try:
-		days[int(name)] = toml.load(filename)
-	except toml.TomlDecodeError:
-		pass
+	name = int(filename.split(os.sep)[-1].split('.')[0])
+	# try:
+	days[name] = toml.load(filename)
+	# except toml.TomlDecodeError:
+		# pass
 
 
 # Clear the screen
@@ -39,13 +39,13 @@ os.system('cls' if sys.platform.startswith('win') else 'clear')
 
 def main():
 	day_number = 0
-
 	while True:
 		day = days[day_number]
 		if 'notification' in day:
 			for notification in day['notification']:
 				ascii.notification(**notification)
-		input('>>> ')
+		# input('>>> ')
+		day_number += 1
 
 if __name__ == "__main__":
 	main()
\ No newline at end of file
